summaryrefslogtreecommitdiff
path: root/sys
diff options
context:
space:
mode:
Diffstat (limited to 'sys')
-rw-r--r--sys/arch/arc/Makefile6
-rw-r--r--sys/arch/arc/arc/conf.c12
-rw-r--r--sys/arch/arc/arc/machdep.c6
-rw-r--r--sys/arch/arc/arc/pmap.c16
-rw-r--r--sys/arch/arc/arc/trap.c8
-rw-r--r--sys/arch/arc/compile/.cvsignore1
-rw-r--r--sys/arch/arc/conf/Makefile.arc4
-rw-r--r--sys/arch/arc/dev/pccons.c8
-rw-r--r--sys/arch/arc/include/cpu.h4
-rw-r--r--sys/arch/arc/include/param.h10
-rw-r--r--sys/arch/arc/include/pmap.h6
-rw-r--r--sys/arch/arc/pica/picabus.c4
12 files changed, 43 insertions, 42 deletions
diff --git a/sys/arch/arc/Makefile b/sys/arch/arc/Makefile
index d358d6b5abf..c6236276922 100644
--- a/sys/arch/arc/Makefile
+++ b/sys/arch/arc/Makefile
@@ -1,14 +1,14 @@
# from: @(#)Makefile 8.1 (Berkeley) 6/16/93
-# $Id: Makefile,v 1.1 1996/06/24 09:07:17 pefo Exp $
+# $Id: Makefile,v 1.2 1996/07/16 07:46:11 pefo Exp $
-# Makefile for pica links, tags file
+# Makefile for arc links, tags file
.include "../../kern/Make.tags.inc"
all:
@echo "make links or tags only"
-DIRS= conf dev dist include pica
+DIRS= arc conf dev include isa pica
links::
-for i in ${DIRS}; do \
diff --git a/sys/arch/arc/arc/machdep.c b/sys/arch/arc/arc/machdep.c
index 3ad8d5e1f7b..cf99cea878a 100644
--- a/sys/arch/arc/arc/machdep.c
+++ b/sys/arch/arc/arc/machdep.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: machdep.c,v 1.1 1996/06/24 09:07:21 pefo Exp $ */
+/* $OpenBSD: machdep.c,v 1.2 1996/07/16 07:46:12 pefo Exp $ */
/*
* Copyright (c) 1988 University of Utah.
* Copyright (c) 1992, 1993
@@ -38,7 +38,7 @@
* SUCH DAMAGE.
*
* from: @(#)machdep.c 8.3 (Berkeley) 1/12/94
- * $Id: machdep.c,v 1.1 1996/06/24 09:07:21 pefo Exp $
+ * $Id: machdep.c,v 1.2 1996/07/16 07:46:12 pefo Exp $
*/
/* from: Utah Hdr: machdep.c 1.63 91/04/24 */
@@ -175,7 +175,7 @@ mips_init(argc, argv, code)
vid_print_string("Starting\n");
/* clear the BSS segment in NetBSD code */
- v = (caddr_t)pica_round_page(end);
+ v = (caddr_t)mips_round_page(end);
bzero(edata, v - edata);
/* check what model platform we are running on */
diff --git a/sys/arch/arc/arc/pmap.c b/sys/arch/arc/arc/pmap.c
index f5baee426c6..f350e213396 100644
--- a/sys/arch/arc/arc/pmap.c
+++ b/sys/arch/arc/arc/pmap.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: pmap.c,v 1.1 1996/06/24 09:07:21 pefo Exp $ */
+/* $OpenBSD: pmap.c,v 1.2 1996/07/16 07:46:13 pefo Exp $ */
/*
* Copyright (c) 1992, 1993
* The Regents of the University of California. All rights reserved.
@@ -36,7 +36,7 @@
* SUCH DAMAGE.
*
* from: @(#)pmap.c 8.4 (Berkeley) 1/26/94
- * $Id: pmap.c,v 1.1 1996/06/24 09:07:21 pefo Exp $
+ * $Id: pmap.c,v 1.2 1996/07/16 07:46:13 pefo Exp $
*/
/*
@@ -206,17 +206,17 @@ pmap_bootstrap(firstaddr)
* phys_start and phys_end but its better to use kseg0 addresses
* rather than kernel virtual addresses mapped through the TLB.
*/
- i = maxmem - pica_btop(CACHED_TO_PHYS(firstaddr));
+ i = maxmem - mips_btop(CACHED_TO_PHYS(firstaddr));
valloc(pv_table, struct pv_entry, i);
/*
* Clear allocated memory.
*/
- firstaddr = pica_round_page(firstaddr);
+ firstaddr = mips_round_page(firstaddr);
bzero((caddr_t)start, firstaddr - start);
avail_start = CACHED_TO_PHYS(firstaddr);
- avail_end = pica_ptob(maxmem);
+ avail_end = mips_ptob(maxmem);
mem_size = avail_end - avail_start;
virtual_avail = VM_MIN_KERNEL_ADDRESS;
@@ -540,7 +540,7 @@ pmap_remove(pmap, sva, eva)
panic("pmap_remove: uva not in range");
#endif
while (sva < eva) {
- nssva = pica_trunc_seg(sva) + NBSEG;
+ nssva = mips_trunc_seg(sva) + NBSEG;
if (nssva == 0 || nssva > eva)
nssva = eva;
/*
@@ -710,7 +710,7 @@ pmap_protect(pmap, sva, eva, prot)
panic("pmap_protect: uva not in range");
#endif
while (sva < eva) {
- nssva = pica_trunc_seg(sva) + NBSEG;
+ nssva = mips_trunc_seg(sva) + NBSEG;
if (nssva == 0 || nssva > eva)
nssva = eva;
/*
@@ -1412,7 +1412,7 @@ pmap_phys_address(ppn)
if (pmapdebug & PDB_FOLLOW)
printf("pmap_phys_address(%x)\n", ppn);
#endif
- return (pica_ptob(ppn));
+ return (mips_ptob(ppn));
}
/*
diff --git a/sys/arch/arc/arc/trap.c b/sys/arch/arc/arc/trap.c
index 99b6ba53a6f..aa58bd7a90c 100644
--- a/sys/arch/arc/arc/trap.c
+++ b/sys/arch/arc/arc/trap.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: trap.c,v 1.1 1996/06/24 09:07:21 pefo Exp $ */
+/* $OpenBSD: trap.c,v 1.2 1996/07/16 07:46:14 pefo Exp $ */
/*
* Copyright (c) 1988 University of Utah.
* Copyright (c) 1992, 1993
@@ -39,7 +39,7 @@
* from: Utah Hdr: trap.c 1.32 91/04/06
*
* from: @(#)trap.c 8.5 (Berkeley) 1/11/94
- * $Id: trap.c,v 1.1 1996/06/24 09:07:21 pefo Exp $
+ * $Id: trap.c,v 1.2 1996/07/16 07:46:14 pefo Exp $
*/
#include <sys/param.h>
@@ -289,7 +289,7 @@ trap(statusReg, causeReg, vadr, pc, args)
if (!(entry & PG_V) || (entry & PG_M))
panic("trap: ktlbmod: invalid pte");
#endif
- if (pmap_is_page_ro(pmap_kernel(), pica_trunc_page(vadr), entry)) {
+ if (pmap_is_page_ro(pmap_kernel(), mips_trunc_page(vadr), entry)) {
/* write to read only page in the kernel */
ftype = VM_PROT_WRITE;
goto kernel_fault;
@@ -326,7 +326,7 @@ trap(statusReg, causeReg, vadr, pc, args)
panic("trap: utlbmod: invalid pte");
}
#endif
- if (pmap_is_page_ro(pmap, pica_trunc_page(vadr), entry)) {
+ if (pmap_is_page_ro(pmap, mips_trunc_page(vadr), entry)) {
/* write to read only page */
ftype = VM_PROT_WRITE;
goto dofault;
diff --git a/sys/arch/arc/compile/.cvsignore b/sys/arch/arc/compile/.cvsignore
index db5b0e04a3a..7b6d9a25b01 100644
--- a/sys/arch/arc/compile/.cvsignore
+++ b/sys/arch/arc/compile/.cvsignore
@@ -1 +1,2 @@
GENERIC
+PICA
diff --git a/sys/arch/arc/conf/Makefile.arc b/sys/arch/arc/conf/Makefile.arc
index d78ad52e462..cee91a9c28e 100644
--- a/sys/arch/arc/conf/Makefile.arc
+++ b/sys/arch/arc/conf/Makefile.arc
@@ -1,4 +1,4 @@
-# $OpenBSD: Makefile.arc,v 1.1 1996/06/24 09:07:20 pefo Exp $
+# $OpenBSD: Makefile.arc,v 1.2 1996/07/16 07:46:15 pefo Exp $
# @(#)Makefile.arc 8.2 (Berkeley) 2/16/94
#
@@ -109,7 +109,7 @@ newvers:
${CC} $(CFLAGS) -c vers.c
clean::
- rm -f eddep bsd bsd.gdb tags *.o locore.i [a-z]*.s \
+ rm -f eddep bsd bsd.gdb bsd.ecoff tags *.o locore.i [a-z]*.s \
Errs errs linterrs makelinks genassym
lint: /tmp param.c
diff --git a/sys/arch/arc/dev/pccons.c b/sys/arch/arc/dev/pccons.c
index edc39878791..111d47f2fc4 100644
--- a/sys/arch/arc/dev/pccons.c
+++ b/sys/arch/arc/dev/pccons.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: pccons.c,v 1.1 1996/06/24 09:07:19 pefo Exp $ */
+/* $OpenBSD: pccons.c,v 1.2 1996/07/16 07:46:16 pefo Exp $ */
/* $NetBSD: pccons.c,v 1.89 1995/05/04 19:35:20 cgd Exp $ */
/*-
@@ -1701,11 +1701,11 @@ pcmmap(dev, offset, nprot)
{
if (offset >= 0xa0000 && offset < 0xc0000)
- return pica_btop(PICA_P_LOCAL_VIDEO + offset);
+ return mips_btop(PICA_P_LOCAL_VIDEO + offset);
if (offset >= 0x0000 && offset < 0x10000)
- return pica_btop(PICA_P_LOCAL_VIDEO_CTRL + offset);
+ return mips_btop(PICA_P_LOCAL_VIDEO_CTRL + offset);
if (offset >= 0x40000000 && offset < 0x40800000)
- return pica_btop(PICA_P_LOCAL_VIDEO + offset - 0x40000000);
+ return mips_btop(PICA_P_LOCAL_VIDEO + offset - 0x40000000);
return -1;
}
diff --git a/sys/arch/arc/include/cpu.h b/sys/arch/arc/include/cpu.h
index a15717c3374..f43cf199abf 100644
--- a/sys/arch/arc/include/cpu.h
+++ b/sys/arch/arc/include/cpu.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: cpu.h,v 1.1 1996/06/24 09:07:17 pefo Exp $ */
+/* $OpenBSD: cpu.h,v 1.2 1996/07/16 07:46:17 pefo Exp $ */
/*-
* Copyright (c) 1992, 1993
@@ -274,7 +274,7 @@
#endif /* _KERNEL */
/*
- * Exported definitions unique to pica/mips cpu support.
+ * Exported definitions unique to mips cpu support.
*/
/*
diff --git a/sys/arch/arc/include/param.h b/sys/arch/arc/include/param.h
index a24f4b327c4..9c87d6683c7 100644
--- a/sys/arch/arc/include/param.h
+++ b/sys/arch/arc/include/param.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: param.h,v 1.1 1996/06/24 09:07:17 pefo Exp $ */
+/* $OpenBSD: param.h,v 1.2 1996/07/16 07:46:17 pefo Exp $ */
/*
* Copyright (c) 1988 University of Utah.
@@ -137,10 +137,10 @@
/*
* Mach derived conversion macros
*/
-#define pica_round_page(x) ((((unsigned)(x)) + NBPG - 1) & ~(NBPG-1))
-#define pica_trunc_page(x) ((unsigned)(x) & ~(NBPG-1))
-#define pica_btop(x) ((unsigned)(x) >> PGSHIFT)
-#define pica_ptob(x) ((unsigned)(x) << PGSHIFT)
+#define mips_round_page(x) ((((unsigned)(x)) + NBPG - 1) & ~(NBPG-1))
+#define mips_trunc_page(x) ((unsigned)(x) & ~(NBPG-1))
+#define mips_btop(x) ((unsigned)(x) >> PGSHIFT)
+#define mips_ptob(x) ((unsigned)(x) << PGSHIFT)
#ifdef _KERNEL
#ifndef _LOCORE
diff --git a/sys/arch/arc/include/pmap.h b/sys/arch/arc/include/pmap.h
index 6582b7b13ba..216571f641b 100644
--- a/sys/arch/arc/include/pmap.h
+++ b/sys/arch/arc/include/pmap.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: pmap.h,v 1.1 1996/06/24 09:07:17 pefo Exp $ */
+/* $OpenBSD: pmap.h,v 1.2 1996/07/16 07:46:18 pefo Exp $ */
/*
* Copyright (c) 1987 Carnegie-Mellon University
@@ -64,8 +64,8 @@
* dynamically allocated at boot time.
*/
-#define pica_trunc_seg(x) ((vm_offset_t)(x) & ~SEGOFSET)
-#define pica_round_seg(x) (((vm_offset_t)(x) + SEGOFSET) & ~SEGOFSET)
+#define mips_trunc_seg(x) ((vm_offset_t)(x) & ~SEGOFSET)
+#define mips_round_seg(x) (((vm_offset_t)(x) + SEGOFSET) & ~SEGOFSET)
#define pmap_segmap(m, v) ((m)->pm_segtab->seg_tab[((v) >> SEGSHIFT)])
#define PMAP_SEGTABSIZE 512
diff --git a/sys/arch/arc/pica/picabus.c b/sys/arch/arc/pica/picabus.c
index f6058cf8b4d..590f92b500f 100644
--- a/sys/arch/arc/pica/picabus.c
+++ b/sys/arch/arc/pica/picabus.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: picabus.c,v 1.1 1996/06/24 09:07:18 pefo Exp $ */
+/* $OpenBSD: picabus.c,v 1.2 1996/07/16 07:46:18 pefo Exp $ */
/* $NetBSD: tc.c,v 1.2 1995/03/08 00:39:05 cgd Exp $ */
/*
@@ -98,7 +98,7 @@ struct pica_dev {
struct pica_dev acer_pica_61_cpu[] = {
{{ "dallas_rtc",0, 0, },
0, pica_intrnull, (void *)PICA_SYS_CLOCK, },
- {{ "lpt", 1, 0, },
+ {{ "lpr", 1, 0, },
PICA_SYS_LB_IE_PAR1, pica_intrnull, (void *)PICA_SYS_PAR1, },
{{ "fdc", 2, 0, },
PICA_SYS_LB_IE_FLOPPY,pica_intrnull, (void *)PICA_SYS_FLOPPY, },
diff --git a/sys/arch/arc/arc/conf.c b/sys/arch/arc/arc/conf.c
index 6a19c28d1a2..e6e302a2320 100644
--- a/sys/arch/arc/arc/conf.c
+++ b/sys/arch/arc/arc/conf.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: conf.c,v 1.3 1996/07/15 14:57:00 mickey Exp $ */
+/* $OpenBSD: conf.c,v 1.4 1996/07/16 07:46:12 pefo Exp $ */
/*
* Copyright (c) 1992, 1993
@@ -36,7 +36,7 @@
* SUCH DAMAGE.
*
* from: @(#)conf.c 8.2 (Berkeley) 11/14/93
- * $Id: conf.c,v 1.3 1996/07/15 14:57:00 mickey Exp $
+ * $Id: conf.c,v 1.4 1996/07/16 07:46:12 pefo Exp $
*/
#include <sys/param.h>
@@ -97,7 +97,7 @@ int nblkdev = sizeof (bdevsw) / sizeof (bdevsw[0]);
dev_init(c,n,tty), ttselect, dev_init(c,n,mmap), D_TTY }
/* open, close, write, ioctl */
-#define cdev_lpt_init(c,n) { \
+#define cdev_lpr_init(c,n) { \
dev_init(c,n,open), dev_init(c,n,close), (dev_type_read((*))) enodev, \
dev_init(c,n,write), dev_init(c,n,ioctl), (dev_type_stop((*))) enodev, \
0, seltrue, (dev_type_mmap((*))) enodev }
@@ -133,8 +133,8 @@ cdev_decl(vnd);
cdev_decl(bpf);
#include "ace.h"
cdev_decl(ace);
-#include "lpt.h"
-cdev_decl(lpt);
+#include "lpr.h"
+cdev_decl(lpr);
cdev_decl(sd);
#include "pc.h"
cdev_decl(pc);
@@ -171,7 +171,7 @@ struct cdevsw cdevsw[] =
cdev_disk_init(NFDC,fd), /* 13: Floppy disk */
cdev_pc_init(NPC,pc), /* 14: builtin pc style console dev */
cdev_mouse_init(1,pms), /* 15: builtin PS2 style mouse */
- cdev_lpt_init(NLPT,lpt), /* 16: lpt paralell printer interface */
+ cdev_lpr_init(NLPR,lpr), /* 16: lpr paralell printer interface */
cdev_tty_init(NACE,ace), /* 17: ace 16C450 serial interface */
cdev_notdef(), /* 18: */
cdev_notdef(), /* 19: */